@@ -76,8 +76,10 @@ export class ServerController extends React.Component<
     } else {
       return (
         <fieldset>
-          <legend>{this.props.serverName}</legend>
-          <p>
+          <legend style={{ wordBreak: 'break-all' }}>
+            {this.props.serverName}
+          </legend>
+          <p style={{ wordBreak: 'break-all' }}>
             {this.props.serverAddress}
             <button
               className="btn-invisible"
