@@ -29,7 +29,7 @@ export class ServerManager extends ReactWidget {
         <h4>TigerGraph Database Server</h4>
         <p>
           <a
-            href="https://docs.tigergraph.com/ml-workbench/current/overview/"
+            href="https://docs.tigergraph.com/ml-workbench/current/intro/"
             target="_blank"
           >
             Help
